/*
    Copyright (C) 2022 Tenable, Inc.

	Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

		http://www.apache.org/licenses/LICENSE-2.0

	Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.
*/

package opa

import (
	"context"
	"time"

	"github.com/tenable/terrascan/pkg/policy"
)

// EngineStats Contains misc stats
type EngineStats struct {
	ruleCount         int
	regoFileCount     int
	metadataFileCount int
	metadataCount     int
	runTime           time.Duration
}

// Engine Implements the policy engine interface
type Engine struct {
	results     policy.EngineOutput
	context     context.Context
	regoFileMap map[string][]byte
	regoDataMap map[string]*policy.RegoData
	stats       EngineStats
}
